---
title: 百科
---

ABM 和 SES 这些概念涉及非常专业的具体领域，很少有研究者同时涉足两者。
为了说明 `ABSESpy` 为什么要将两者结合，或者帮助关注该方法的学者熟悉这两个领域中的某些概念，我们创建了这个百科页面。

> [!INFO] 进行中
> 作者团队参考公开发表的、经过同行评议的论文，努力做到言简意赅且依据详实。我们真诚希望相关领域的学者愿意参与到本百科页的共建中。如果发现任何错误，请[及时联系我们](https://github.com/SongshGeoLab/ABSESpy/issues)。

<div class="grid" markdown>

[:books: __概念__](concepts.md) 基本相关概念介绍
{ .card }

[:books: __材料__](materials.md) 学习背景的有用链接
{ .card }

[:books: __参考__](about.md) `ABSESpy` 使用的一些优秀学术参考
{ .card }

[:books: __论文__](../paper/paper.md) 介绍 `ABSESpy` 如何帮助这一领域的论文
{ .card }

</div>

